@@ -65,9 +65,10 @@ def VacancyAnalysis():
     print(cfg.pipeline.enable_training_assets)
 
     flat = cfg.as_flat()  
-
+    proc = ClusterProcessor(cfg=cfg)         
+    proc.run()
     
-    if cfg.pipeline.use_external_reference == False:
+    if cfg.pipeline.use_external_reference:
         config_dict = {
             "paths": {
                 "defect_inputs": [str(cfg.paths.defect_inputs[0])]
@@ -78,13 +79,22 @@ def VacancyAnalysis():
                 "cells": cfg.reference.cells        
             }
         }
-        
-        
-        generator = CrystalStructureGenerator(config_dict, "outputs/dump")
-        dump_path = generator.generate()
+
+    # Después (pasando cfg e input explícito):
     if cfg.pipeline.enable_training_assets:
-        gen = AtomicGraphGenerator()
+        gen = AtomicGraphGenerator(
+            cfg=cfg,
+            input_path=cfg.paths.defect_inputs[0],                # entra por el mismo dump que usás en todo el pipeline
+            neighbor_radius=getattr(cfg.training, "neighbor_radius", None),  # opcional: overrides
+            cutoff=cfg.graph.cutoff,
+            smoothing_level=cfg.preprocessing.smoothing_level_training,
+            iterations=cfg.training.max_graph_variations,
+            max_graph_size=cfg.training.max_graph_size,
+            export_dumps=getattr(cfg.training, "export_dumps", False),
+            seed=getattr(cfg.training, "seed", None),
+        )
         gen.run()
+
     
 
     for FILE in cfg.paths.defect_inputs:
@@ -112,7 +122,6 @@ def VacancyAnalysis():
                 print(f"Número total de vacancias encontradas: {vacancies}")
             else:
                                 
-                cfg = Config.from_file("input_params.json")
                 proc = ClusterProcessor(cfg=cfg)         
                 proc.run()
                 separator = KeyFilesSeparator(cfg.clustering.tolerance,os.path.join("outputs/json", "clusters.json"))
